# cipher_craft/__init__.py

# Expose selected functions and classes at the package level
from .generator import generate_password
from .passphrase_generator import generate_passphrase
from .strength_checker import check_strength
from .expiry_checker import check_password_expiry
from .entropy_calculator import calculate_entropy

__all__ = [
    "generate_password",
    "generate_passphrase",
    "check_password_strength",
    "check_password_expiry",
    "calculate_entropy",
]